<?php
/**
 * $Id: slideshow_creator.cck.inc,v 1.1.2.2 2007/07/31 02:13:30 brmassa Exp $
 * @file slideshow_creator.cck.inc
 * @author Bruno Massa http://drupal.org/user/67164
 * Create true slideshows using CCK module.
 * Project Page  : http://drupal.org/project/slideshow_creator
 * Support Queue : http://drupal.org/project/issues/slideshow_creator
 */

/**
 * Implementation of hook_field_info().
 */
function slideshow_creator_field_info() {
  return array(
    'slideshow' => array('label' => 'Slideshow'),
  );
}

/**
 * Implementation of hook_field_formatter().
 */
function slideshow_creator_field_formatter($field, $item, $formatter) {
  $attributes = array();
  array_push($attributes, empty($item['name'])   ? '' : 'name='.   $item['name']);
  array_push($attributes, empty($item['rotate']) ? '' : 'rotate='. $item['rotate']);
  array_push($attributes, empty($item['blend'])  ? '' : 'blend='.  $item['blend']);
  array_push($attributes, empty($item['height']) ? '' : 'height='. $item['height']);
  array_push($attributes, empty($item['width'])  ? '' : 'width='.  $item['width']);
  array_push($attributes, empty($item['layout']) ? '' : 'layout='. $item['layout']);
  if (!empty($item['url']) or !empty($item['dir'])) {
    if ($urls = split("\n", $item['url'])) {
      while (list($index, $url) = each($urls)) {
        $urls[$index] = 'img=|'. $url;
      }
    }
    if ($dirs = split("\n", $item['dir'])) {
      while (list($index, $url) = each($dirs)) {
        $dirs[$index] = 'dir=|'. $url;
      }
    }
    $images = array_merge($urls, $dirs);
    return slideshow_creator_process_text('[slideshow: 2,'. implode(',', $attributes) .','. implode(',', $images) .']');
  }
  return '';
}

/**
 * Implementation of hook_field_formatter_info().
 */
function slideshow_creator_field_formatter_info() {
  $formatters = array(
    'default' => array(
      'label' => 'Default',
      'field types' => array('slideshow'),
    ),
  );
  return $formatters;
}

/**
 * Implementation of hook_field_settings(): how this field should behave
 */
function slideshow_creator_field_settings($op, $field) {
  if ($op == 'database columns') {
    $columns = array(
      'url'     => array('type' => 'text'),
      'dir'     => array('type' => 'text'),
      'name'    => array('type' => 'varchar', 'length' => 255, 'not null' => true),
      'layout'  => array('type' => 'varchar', 'length' => 255),
      'rotate'  => array('type' => 'float'),
      'blend'   => array('type' => 'float'),
      'height'  => array('type' => 'float'),
      'width'   => array('type' => 'float')
    );
    return $columns;
  }
}

/**
 * Implementation of hook_widget().
 *
 * defines the widget fields
 */
function slideshow_creator_widget($op, &$node, $field, &$items) {
  switch ($op) {
    case 'form':
      $form = array();
      $form[$field['field_name']] = array(
        '#type'          => 'fieldset',
        '#title'         => t($field['widget']['label']),
        '#weight'        => $field['widget']['weight'],
        '#collapsible'   => true,
        '#collapsed'     => false,
        '#tree'          => true
      );
      $form[$field['field_name']][0]['url'] = array(
        '#type'          => 'textarea',
        '#title'         => t('Image'),
        '#default_value' => $items[0]['url'],
        '#description'   => t('On each line, fill your slides using the <b>IMAGE_URL|LINK|TITLE|DESCRIPTION|TARGET</b> pattern.')
      );
      $form[$field['field_name']][0]['dir'] = array(
        '#type'          => 'textarea',
        '#title'         => t('Image directory'),
        '#default_value' => $items[0]['dir'],
        '#description'   => t('On each line, fill your slides using the <b>DIR_IMAGE|DIR_RECURSIVE|DIR_LINK|TITLE|DESCRIPTION|TARGET</b> pattern.')
      );
      $form[$field['field_name']][0]['rotate'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Rotation'),
        '#default_value' => $items[0]['rotate'],
        '#description'   => t('The rotation speed, in seconds. Leave it blank for no rotation.'),
        '#weight'        => 1
      );
      $form[$field['field_name']][0]['blend'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Blend'),
        '#default_value' => $items[0]['blend'],
        '#description'   => t('The blending speed, in seconds. Leave it blank for no blending.'),
        '#weight'        => 1
      );
      $form[$field['field_name']][0]['width'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Width'),
        '#default_value' => $items[0]['width'],
        '#description'   => t('The image width, in pixels.'),
        '#weight'        => 2
      );
      $form[$field['field_name']][0]['height'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Height'),
        '#default_value' => $items[0]['height'],
        '#description'   => t('The image height, in pixels.'),
        '#weight'        => 2
      );
      $form[$field['field_name']][0]['layout'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Layout'),
        '#default_value' => $items[0]['layout'],
        '#description'   => t('The customized layout name. Leave it blank for default layout.'),
        '#weight'        => 3
      );
      return $form;
    case 'validate':
      $error_field = $field['field_name'] .'][0][';
      if (!empty($items[0]['height']) and !is_numeric($items[0]['height'])) {;
        form_set_error($error_field .'height', t('Height') .' '. t('must be a number.'));
      }
      if (!empty($items[0]['width']) and !is_numeric($items[0]['width'])) {
        form_set_error($error_field .'width', t('Width') .' '. t('must be a number.'));
      }
      if (!empty($items[0]['rotate']) and !is_numeric($items[0]['rotate'])) {
        form_set_error($error_field .'rotate', t('Rotation') .' '. t('must be a number.'));
      }
      if (!empty($items[0]['blend']) and !is_numeric($items[0]['blend'])) {
        form_set_error($error_field .'blend', t('Blend') .' '. t('must be a number.'));
      }
      return;
  }
}

/**
 * Implementation of hook_widget_info().
 */
function slideshow_creator_widget_info() {
  return array(
    'slideshow' => array(
      'label'       => t('Slideshow'),
      'field types' => array('slideshow'),
    ),
  );
}

/**
 * Format the slideshow widget
 *
 * @ingroup themeable
 */
function theme_slideshow_creator_view_image($file, $alt = '', $title = '', $attributes = null, $getsize = true) {
  return theme('slideshow_creator_image', $file, $alt, $title, $attributes , $getsize);
}
